@@ -8,7 +8,7 @@
 #################################################################
 
 ##Author: Christos Zamantzas <christos.zamantzas@gmail.com>
-Version = '0.3-2'
+Version = '0.3-3'
 
 import os
 import sys
@@ -131,7 +131,7 @@ class SwappolubeAbout(QMainWindow):
                                    <br>
                                    <br>
                                    <br><b>Thanks to :</b>
-                                   <br><b>debernalis</b> at talk.maemo.org for
+                                   <br><b>debernardis</b> at talk.maemo.org for
                                    <br>the name, icon and the application idea.
                                    <br>
                                    <br><b>Benoit HERVIER</b> at http://khertan.net/
